<?php
/**
 * Child Pages Card
 *
 * @package    Child Pages Card
 * @subpackage ChildPagesCard Main Functions
/*
	Copyright (c) 2019- Katsushi Kawamori (email : dodesyoswift312@gmail.com)
	This program is free software; you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation; version 2 of the License.

	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with this program; if not, write to the Free Software
	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

$childpagescard = new ChildPagesCard();

/** ==================================================
 * Main Functions
 */
class ChildPagesCard {

	/** ==================================================
	 * Construct
	 *
	 * @since   1.00
	 */
	public function __construct() {

		add_action( 'init', array( $this, 'childpagescard_block_init' ) );
		add_action( 'wp_footer', array( $this, 'load_style' ) );
		add_action( 'admin_enqueue_scripts', array( $this, 'load_style' ) );
		add_shortcode( 'childpagescard', array( $this, 'childpagescard_func' ) );
	}

	/** ==================================================
	 * Attribute block
	 *
	 * @since 1.00
	 */
	public function childpagescard_block_init() {

		$childpagescard_settings = get_option(
			'childpagescard_settings',
			array(
				'pageid' => null,
				'sort' => 'ASC',
				'excerpt' => 500,
				'imgsize' => 100,
				'color' => '#7db4e6',
			)
		);

		register_block_type(
			plugin_dir_path( __DIR__ ) . 'block/build',
			array(
				'attributes'      => array(
					'pageid'   => array(
						'type'    => 'string',
						'default' => $childpagescard_settings['pageid'],
					),
					'sort'   => array(
						'type'    => 'string',
						'default' => $childpagescard_settings['sort'],
					),
					'excerpt'   => array(
						'type'    => 'number',
						'default' => $childpagescard_settings['excerpt'],
					),
					'imgsize'   => array(
						'type'    => 'number',
						'default' => $childpagescard_settings['imgsize'],
					),
					'color'    => array(
						'type'    => 'string',
						'default' => $childpagescard_settings['color'],
					),
				),
				'render_callback' => array( $this, 'childpagescard_func' ),
				'title' => _x( 'Child Pages Card', 'block title', 'child-pages-card' ),
				'description' => _x( 'Displays child page archives in card form.', 'block description', 'child-pages-card' ),
				'keywords' => array(
					_x( 'archives', 'block keyword', 'child-pages-card' ),
					_x( 'child page', 'block keyword', 'child-pages-card' ),
					_x( 'page', 'block keyword', 'child-pages-card' ),
				),
			)
		);

		$script_handle = generate_block_asset_handle( 'child-pages/childpagescard-block', 'editorScript' );
		wp_set_script_translations( $script_handle, 'child-pages-card' );
	}

	/** ==================================================
	 * Short code
	 *
	 * @param array  $atts  attributes.
	 * @param string $content  contents.
	 * @return string $content  contents.
	 * @since 1.00
	 */
	public function childpagescard_func( $atts, $content = null ) {

		$a = shortcode_atts(
			array(
				'pageid'  => '',
				'sort'    => '',
				'excerpt' => '',
				'imgsize' => '',
				'color'   => '',
			),
			$atts
		);

		$settings_tbl = get_option(
			'childpagescard_settings',
			array(
				'pageid' => get_the_ID(),
				'sort' => 'ASC',
				'excerpt' => 500,
				'imgsize' => 100,
				'color' => '#7db4e6',
			)
		);

		foreach ( $settings_tbl as $key => $value ) {
			$shortcodekey = strtolower( $key );
			if ( empty( $a[ $shortcodekey ] ) ) {
				if ( 'excerpt' === $key || 'imgsize' === $key ) {
					if ( is_numeric( $a[ $shortcodekey ] ) ) {
						$a[ $shortcodekey ] = 0;
					} else {
						$a[ $shortcodekey ] = $value;
					}
				} else {
					$a[ $shortcodekey ] = $value;
				}
			} elseif ( strtolower( $a[ $shortcodekey ] ) === 'false' ) {
					$a[ $shortcodekey ] = null;
			}
		}

		return do_shortcode( $this->childpagescard( $a ) );
	}

	/** ==================================================
	 * Child Page Card
	 *
	 * @param array $settings  settings.
	 * @return string $content  contents.
	 * @since 1.00
	 */
	private function childpagescard( $settings ) {

		$contents = null;

		if ( ! empty( $settings['pageid'] ) ) {
			/* child pages */
			$args = array(
				'post_parent' => intval( $settings['pageid'] ),
				'post_status' => 'publish',
				'post_type'   => 'page',
				'order'       => $settings['sort'],
				'orderby'     => 'menu_order',
			);
			$children_array = get_children( $args );

			if ( count( $children_array ) > 0 ) {
				foreach ( $children_array as $child ) {

					$title = esc_html( $child->post_title );

					if ( function_exists( 'mb_substr' ) ) {
						$excerpt = mb_substr( strip_shortcodes( wp_strip_all_tags( $child->post_content ) ), 0, $settings['excerpt'] ) . '...';
					} else {
						$excerpt = substr( strip_shortcodes( wp_strip_all_tags( $child->post_content ) ), 0, $settings['excerpt'] ) . '...';
					}

					$url = get_permalink( $child->ID );

					/* thumbnail */
					$img_width = $settings['imgsize'];
					$img_height = $settings['imgsize'];

					global $wpdb;
					$thumb_id = $wpdb->get_var(
						$wpdb->prepare(
							"
								SELECT	meta_value
								FROM	{$wpdb->prefix}postmeta
								WHERE	post_id = %d
								AND		meta_key = '_thumbnail_id'
							",
							$child->ID
						)
					);

					if ( $settings['imgsize'] > 0 ) {
						if ( $thumb_id && wp_attachment_is_image( $thumb_id ) ) {
							$img = wp_get_attachment_image_src( $thumb_id, array( $img_width, $img_height ) );
							$img_tag = '<img style="border-radius: 5px;" src="' . esc_attr( $img[0] ) . '" alt="' . $title . '" width="' . esc_attr( $img[1] ) . ' " height="' . esc_attr( $img[2] ) . '" />';
						} else if ( get_option( 'site_icon' ) ) {
							$siteicon_id = get_option( 'site_icon' );
							if ( wp_attachment_is_image( $siteicon_id ) ) {
								$img = wp_get_attachment_image_src( $siteicon_id, array( $img_width, $img_height ) );
								$img_tag = '<img style="border-radius: 5px;" src="' . esc_attr( $img[0] ) . '" alt="' . $title . '" width="' . esc_attr( $img[1] ) . ' " height="' . esc_attr( $img[2] ) . '" />';
							} else {
								$img_tag = '<img style="border-radius: 5px;" src="' . includes_url() . 'images/w-logo-blue.png" alt="' . $title . '" width="' . esc_attr( $img_width ) . ' " height="' . esc_attr( $img_height ) . '" />';
							}
						} else {
							$img_tag = '<img style="border-radius: 5px;" src="' . includes_url() . 'images/w-logo-blue.png" alt="' . $title . '" width="' . esc_attr( $img_width ) . ' " height="' . esc_attr( $img_height ) . '" />';
						}
					}

					$subject = $title . ' - ' . get_option( 'blogname' );

					$contents .= '<div class="childpagescard_wrap">';
					$contents .= '<a style="text-decoration: none;" href="' . esc_url( $url ) . '">';
					if ( $settings['imgsize'] > 0 ) {
						$contents .= '<div style="float: right; padding: 10px;">' . $img_tag . '</div>';
					}
					$contents .= '<div class="childpagescard_inner">';
					$contents .= '<div class="childpagescard_border" style="border-left: solid 5px ' . esc_attr( $settings['color'] ) . '; ">';
					$contents .= '<div class="childpagescard_title">' . $subject . '</div>';
					if ( $settings['excerpt'] > 0 ) {
						$contents .= '<div class="childpagescard_description">' . $excerpt . '</div>';
					}
					$contents .= '</div>';
					$contents .= '</div>';
					$contents .= '<div style="clear: both;"></div>';
					$contents .= '</a>';
					$contents .= '</div>';

				}
			} else {
				$contents .= '<div style="text-align: center;">';
				$contents .= '<div><strong><span class="dashicons dashicons-editor-ul" style="position: relative; top: 5px;"></span>Child Pages Card</strong></div>';
				/* translators: Input Page ID */
				$contents .= esc_html( sprintf( __( 'Please input "%1$s".', 'child-pages-card' ), __( 'ID of the parent page', 'child-pages-card' ) ) );
				$contents .= '</div>';
			}
		} else {
			$contents .= '<div style="text-align: center;">';
			$contents .= '<div><strong><span class="dashicons dashicons-editor-ul" style="position: relative; top: 5px;"></span>Child Pages Card</strong></div>';
			/* translators: Input Page ID */
			$contents .= esc_html( sprintf( __( 'Please input "%1$s".', 'child-pages-card' ), __( 'ID of the parent page', 'child-pages-card' ) ) );
			$contents .= '</div>';
		}

		return $contents;
	}

	/** ==================================================
	 * Load Style
	 *
	 * @since 1.06
	 */
	public function load_style() {

		wp_enqueue_style( 'child-pages-card', plugin_dir_url( __DIR__ ) . 'css/childpagescard.css', array(), '1.00' );
		wp_add_inline_style( 'child-pages-card', get_option( 'childpagescard_css', '.childpagescard_wrap { border: 1px solid #ddd; word-wrap:break-word; max-width: 100%; border-radius: 5px; margin: 30px; } .childpagescard_inner { line-height: 120%; padding: 10px; } .childpagescard_border { padding: 0.25em 0.25em; color: #494949; background: transparent; } .childpagescard_title { font-weight: bold; display: block; } .childpagescard_description { color: #333; }' ) );
	}
}
